import 'dart:async';
import 'package:flutter/foundation.dart';
import 'src/report_error.dart';
import 'src/utils.dart';

import 'package:flutter/services.dart';

class XMonitorFlutter extends ReportError {
  static const MethodChannel _channel =
      const MethodChannel('x_monitor_flutter');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// 捕捉异常数据
  void catchRun<T>(T callback()) {
    // 用户标本-采样频率控制
    double userRandom = double.parse(this.config['userRandom'].toString());
    if (Utils.getRandom() >= userRandom) {
      callback();
    } else {
      /// Flutter框架异常捕获
      FlutterError.onError = (FlutterErrorDetails details) {
        print('==Flutter框架异常捕获==');
        this.reportErrorAndLog(details);
      };
      // Zone 捕获所有未处理的异常
      runZoned<Future<Null>>(() async {
        callback();
      }, onError: (Object error, StackTrace stack) async {
        print('**********捕捉到错误**********');
        var details = this.makeErrorDetail(error, stack);
        this.reportErrorAndLog(details);
      });

      this.catchApiException();
      this.catchPerformance();
    }
  }

  /// 捕获api异常数据
  void catchApiException() {}

  /// 捕获性能数据
  void catchPerformance() {}
}
